DockDel
=======

.. image:: https://travis-ci.org/tsalmon/DockDel.svg?branch=master
   :target: https://travis-ci.org/tsalmon/DockDel
   :alt: Travis status

.. image:: https://coveralls.io/repos/tsalmon/DockDel/badge.svg
   :target: https://coveralls.io/r/tsalmon/DockDel
   :alt: Coverage status

.. image:: https://img.shields.io/pypi/v/DockDel.png
   :target: https://pypi.python.org/pypi/DockDel
   :alt: Pypi package

get files of Didel_ in command-line (work in progress).

.. _Didel: http://didel.script.univ-paris-diderot.fr/
